
# Information Security Testing and Assessment Training Content for CyTrONE

The cybersecurity training content included in this package is created
and maintained by the Cyber Range Organization and Design (CROND)
NEC-endowed chair at the Japan Advance Institute of Science and
Technology (JAIST), Ishikawa, Japan. The content is intended for use
with the CyTrONE integrated cybersecurity training framework that we
also develop; for details, and to download CyTrONE, see the
corresponding page on our GitHub web site:
https://github.com/crond-jaist/cytrone/

This training content was inspired by the U.S. National Institute of
Standards and Technology (NIST) "Technical Guide to Information
Security Testing and Assessment", and the questions we created
illustrate most of the technical assessment techniques presented in
the NIST guide. The included questions are organized in two sets
(levels) as explained below, and for each training level both an
English and a Japanese version of the questions are provided:

* **Level 1**: Basic training content that deals with assessment
    techniques such as log and system configuration review, network
    sniffing and vulnerability scanning; one guest VM, playing the
    role of a desktop PC, is needed to solve these questions
* **Level 2**: Training content of medium difficulty that illustrates
    assessment techniques such as network discovery, password cracking
    and penetration testing; two guest VMs, playing the roles of a
    desktop and a web server, are required for solving these questions

Our questions are part of a realistic information security testing and
assessment scenario, with their order following a best-practice
sequence of actions for such a case, and Level 2 being a logical
continuation of Level 1. The correspondence between the assessment
techniques discussed in the NIST guide and our questions is summarized
next (note that the question ids below exclude the language attribute
present in the actual content files):

* **Review Techniques**
  1. *Documentation Review*: L2-07
  2. *Log Review*: L1-05
  3. *Ruleset Review*: L2-01
  4. *System Configuration Review*: L1-01, L1-04, L1-07
  5. *Network Sniffing*: L1-08, L2-02
  6. *File Integrity Checking*: N/A
* **Target Identification and Analysis Techniques**
  1. *Network Discovery*: L1-02, L1-03, L2-04
  2. *Network Port and Service Identification*: L1-09
  3. *Vulnerability Scanning*: L1-10
  4. *Wireless Scanning*: L2-08
* **Target Vulnerability Validation Techniques**
  1. *Password Cracking*: L1-06, L2-03, L2-09
  2. *Penetration Testing*: L2-05, L2-06
  3. *Social Engineering*: L2-10

As it can be seen, almost all of the assessment techniques are
covered, thus providing useful examples of how such techniques could
be used in practice. The only technique we did not include is *File
Integrity Checking*, as we considered it is not appropriate for our
scenario and training format.


## Prerequisites

CyTrONE and its related modules, especially CyRIS, are required to use
the included training content as such. For most of the content, a
virtual machine (VM) image for CyRIS with only a CLI environment is
sufficient, but some of the questions assume the use of a VM with a
GUI desktop environment. You can download such VM images via the link
"*releases*" on the GitHub web page for CyRIS:

* `basevm.tgz` for a CLI environment only VM image
* `basevm_x.tgz` for a GUI environment VM image (the MATE Desktop
  Environment is used)

After download, the VM images must be installed into the appropriate
directory of your CyTrONE/CyRIS setup. The direct link at the time of
writing for the latest CyRIS release, that includes the VM images
mentioned above, is:
https://github.com/crond-jaist/cyris/releases/tag/1.1


## Setup

Follow the steps below in order to install the NIST-inspired training
content in CyTrONE (for further details please consult the CyTrONE
User Guide):

* Copy the included `nist/` directory into the `cytrone/database/`
  folder of your CyTrONE setup
* Update the CyTrONE training database by using as reference the files
  `nist/training-en.yml.nist` (for English) and
  `nist/training-ja.yml.nist` (for Japanese)

Note that some additional setup steps may be required for some
questions, depending on your CyTrONE installation, as explained below:

* **L1-01**: Answer needs to be updated in the files
  `level1-content-XX.yml` depending on the actual kernel release
  number for the VM used as desktop
* **L1-08** and **L2-02**: Section "emulate_traffic_capture_file" in
  the files `level1-range.yml` and `level2-range.yml`, respectively,
  needs to be commented out if noise files are not installed in CyRIS
  (see the CyRIS User Guide for details)
* **L1-10**: Section "emulate_malware" in the file `level1-range.yml`
  needs to be commented out if `cpulimit` is not installed in CyRIS
  (see the CyRIS User Guide for details)
* **L2-03** and **L2-09**: If the host on which the cyber range is
  created is behind a proxy server, the corresponding information
  needs to be passed when executing `john_setup.sh` and
  `aircrack_setup.sh`, respectively, in the file `level2-range.yml`,
  since those scripts download files via `wget`
  * **L2-05** and **L2-06**: The easiest way to solve these questions is
  to use a GUI environment for the desktop VM accessed via the VNC
  protocol, so that a web browser can be used to connect directly to
  the web server located inside the cyber range. Alternatively, an SSH
  tunnel can be used to map the web server port 80 to a port on the
  cyber range host, such as 8080 (e.g., `ssh -f -g -L
  0.0.0.0:8080:WEB_SERVER:80 trainee01@CYBER_RANGE_HOST -p XXXXX -N`),
  then access the webserver via that mapped port (e.g.,
  `http://CYBER_RANGE_HOST:8080`)


## Authors/maintainers

* Authors (in alphabetical order of the last name)
  - Razvan Beuran
  - Zhenguo Hu
  - Cuong Pham
  - Thanh Dat Tang

* Maintainers
  - Razvan Beuran
  - Zhenguo Hu
